@@ -59,6 +59,7 @@ class PluginJsonSchemaNumber(PluginJsonBaseSchema):
     type: Literal["number"]
     minimum: NotRequired[int]
     maximum: NotRequired[int]
+    step: NotRequired[float]
 
 
 class PluginJsonSchemaBoolean(PluginJsonBaseSchema):
@@ -104,6 +105,7 @@ class JsonSchemaNumber(JsonBaseSchema):
     type: Literal["number"]
     minimum: NotRequired[int]
     maximum: NotRequired[int]
+    step: NotRequired[float]
 
 
 class JsonSchemaBoolean(JsonBaseSchema):
@@ -221,7 +223,7 @@ CameraExtension = Literal[
     "intercom",
 ]
 
-Point = tuple[int, int]
+Point = tuple[float, float]
 
 ZoneType = Literal["intersect", "contain"]
 
@@ -318,11 +320,96 @@ PropertyValue = Union[
 
 
 # camera device
+ObjectClasses = Literal[
+    "person",
+    "bicycle",
+    "car",
+    "motorcycle",
+    "airplane",
+    "bus",
+    "train",
+    "truck",
+    "boat",
+    "traffic light",
+    "fire hydrant",
+    "stop sign",
+    "parking meter",
+    "bench",
+    "bird",
+    "cat",
+    "dog",
+    "horse",
+    "sheep",
+    "cow",
+    "elephant",
+    "bear",
+    "zebra",
+    "giraffe",
+    "backpack",
+    "umbrella",
+    "handbag",
+    "tie",
+    "suitcase",
+    "frisbee",
+    "skis",
+    "snowboard",
+    "sports ball",
+    "kite",
+    "baseball bat",
+    "baseball glove",
+    "skateboard",
+    "surfboard",
+    "tennis racket",
+    "bottle",
+    "wine glass",
+    "cup",
+    "fork",
+    "knife",
+    "spoon",
+    "bowl",
+    "banana",
+    "apple",
+    "sandwich",
+    "orange",
+    "broccoli",
+    "carrot",
+    "hot dog",
+    "pizza",
+    "donut",
+    "cake",
+    "chair",
+    "couch",
+    "potted plant",
+    "bed",
+    "dining table",
+    "toilet",
+    "tv",
+    "laptop",
+    "mouse",
+    "remote",
+    "keyboard",
+    "cell phone",
+    "microwave",
+    "oven",
+    "toaster",
+    "sink",
+    "refrigerator",
+    "book",
+    "clock",
+    "vase",
+    "scissors",
+    "teddy bear",
+    "hair drier",
+    "toothbrush",
+    "motion",
+]
+
+
 class Detection(TypedDict):
     id: NotRequired[str]
-    label: str
+    label: ObjectClasses
     confidence: float
-    boundingBox: tuple[int, int, int, int]
+    boundingBox: tuple[float, float, float, float]
     inputWidth: int
     inputHeight: int
     origWidth: int
@@ -443,6 +530,10 @@ class BatteryState(BaseStateBattery, BatterySetEvent): ...
 class BatteryStateWithoutLastEvent(BaseStateWithoutLastEvent, BatterySetEvent): ...
 
 
+class FrameState(MotionState):
+    frame: bytes
+
+
 T = TypeVar(
     "T",
     LightState,
@@ -539,7 +630,7 @@ class PrebufferStateFalse(BasePrebufferState):
 
 PrebufferState = Union[PrebufferStateTrue, PrebufferStateFalse]
 
-PrebufferContainer = Literal["mpegts", "mp4"]
+Container = Literal["mpegts", "mp4"]
 
 
 class CameraDelegate(ABC):
@@ -578,11 +669,9 @@ class CameraSource(Protocol):
     urls: StreamUrls
     # end
 
-    async def update_prebuffering_state(
-        self, container: PrebufferContainer, state: PrebufferState
-    ) -> None: ...
-    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferState: ...
-    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferState]: ...
+    async def update_prebuffering_state(self, container: Container, state: PrebufferState) -> None: ...
+    def get_prebuffering_state(self, container: Container) -> PrebufferState: ...
+    def on_prebuffering(self, container: Container) -> Observable[PrebufferState]: ...
     async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
@@ -650,10 +739,15 @@ class VideoFrame(Protocol):
     def input_height(self) -> int: ...
     @property
     def input_format(self) -> str: ...
+    async def save(self, path: str, options: Optional[ImageOptions] = None) -> None: ...
     async def to_buffer(self, options: Optional[ImageOptions] = None) -> FrameBuffer: ...
     async def to_image(self, options: Optional[ImageOptions] = None) -> FrameImage: ...
 
 
+class MotionFrame(VideoFrame):
+    motion: MotionState
+
+
 SV = TypeVar("SV", bound=StateValue)
 PV = TypeVar("PV", bound=PropertyValue)
 
@@ -713,7 +807,7 @@ class CameraDevice(Protocol):
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
     async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
-    async def get_motion_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
 
